[![PyPI](https://img.shields.io/pypi/v/kukai.svg)](https://pypi.python.org/pypi/kukai)
![License](https://img.shields.io/github/license/casptri/kukai)


# Kukai

Manage and generate your templates with a command-line utility.

- [Documentation]()
- [GitHub](https://github.com/casptri/kukai)
- [PyPi](https://pypi.org/project/kukai/)
- [Licence (MIT)](https://github.com/casptri/kukai/blob/main/LICENSE)

## Installation

Install kukai using pip package manager:
```
python -m pip install kukai
```

## License
kukai is licensed under the MIT license ([LICENSE](https://github.com/casptri/kukai/blob/main/LICENSE) or
<https://opensource.org/licenses/MIT>).

Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in kukai
by you, as defined in the MIT license, shall be licensed as above, without any additional terms or
conditions.
